
/**
 * This class models a bank account.  It has a customer that owns the account and a balance
 */
public class BankAccount
{
  /** the customer that owns the account */
  private Customer customer;
  
  /** the amount of money in the account */
  private double balance;
  
  /** an id for this account */
  private int id;
  
  /** class variable to track the next available id */
  private static int nextId = 0;
  
  /** 
   * Constructor that takes a customer and balance
   */
  public BankAccount(Customer theCustomer, double theBalance)
  {
    customer = theCustomer;
    balance = theBalance;
    id = ++nextId;
  }
  
  /**
   * Method to get the customer 
   * @return the customer associated with the account
   */
  public Customer getCustomer() { return customer; }
  
  /**
   * Method to withdraw money from the account for the given
   * customer
   * @param customer the customer asking to do the withdrawal
   * @param the amount to withdrawal
   * @return the amount withdrawn
   */
  public double withdraw(Customer customer, double amount)
  {
    double result = 0.0;
    
    // if the customer asking to do the withdraw is the owner
    // and the amount they are asking to withdraw is less than
    // or equal to the balance then do the withdraw
    if (this.customer.equals(customer) && amount <= balance)
    {
      balance = balance - amount;
      result = amount;
    }
    return result;
  }
  
  /**
   * Method to deposit money to an account 
   * @param amount the amount to add to the account
   */
  public void deposit(double amount)
  {
    balance = balance + amount;
  }
  
  /**
   * Method to get the current balance
   * @return the current balance in this account
   */
  public double getBalance() { return balance; }
  
  /**
   * Method to return information about this bank account in the
   * form of a string
   * @return id, customer name, and balance in a string
   */
  public String toString()
  {
    return "Account: " + id + " owned by: " + customer.getName() + " balance: " + balance;
  }
 
}