
/**
 * Class that represents a person.  A person has a first name,
 * last name, and a file with their picture in it
 */
public class Person implements Comparable
{
  
  ////////////// fields //////////////////////////////
  
  /** first name of this person */
  private String firstName;
  
  /** last name of this person */
  private String lastName;
  
  /** gender of this person */
  private int gender = UNKNOWN; // the default is unknown
  
  /** the name of a file that has a picture of the person */
  private String pictureFile;
  
  /** constant for unknown gender */
  public static final int UNKNOWN = 0;
  
  /** constant for male gender */
  public static final int MALE = 1;
  
  /** constant for female gender */
  public static final int FEMALE = 2;
  
  /** array for gender strings */
  private static final String[] GENDER_ARRAY = {"unknown","male","female"};
  
  //////////////// constructors //////////////////////////
  
  /** 
   * No argument constructor.  All fields have their default values 
   */
  public Person() {}
  
  /**
   * Constructor that takes the first and last names
   * @param firstName the first name to use
   * @param lastName the last name to use
   */
  public Person(String firstName, String lastName)
  {
    // set the first name and last name
    this.firstName = firstName;
    this.lastName = lastName;
  }
  
  /**
   * Constructor that takes all the data
   * @param firstName the first name to use
   * @param lastName the last name to use
   * @param pictureFile the name of the picture file
   */
  public Person(String firstName, String lastName, String pictureFile)
  {
    // call the other constructor that takes the first and last names
    this(firstName,lastName);
    
    // set the picture file
    this.pictureFile = pictureFile;
  }
  
  ////////////////////////// methods //////////////////////////////
  
  /** 
   * Method to get the first name
   * @return the first name
   */
  public String getFirstName() { return firstName; }
  
  /**
   * Method to get the last name
   * @return the last name
   */
  public String getLastName() { return lastName; }
  
  /**
   * Method to get the picture file name 
   * @return the name of the file with a picture of the person in it
   */
  public String getPictureFile() { return pictureFile; }
  
  /**
   * Method to set the first name
   * @param firstName the first name to use
   */
  public void setFirstName(String firstName) { this.firstName = firstName; }
  
  /**
   * Method to set the last name
   * @param lastName the last name to use
   */
  public void setLastName(String lastName) { this.lastName = lastName; }
  
  /**
   * Method to set the picture file name
   * @param fileName the file name of the picture of this person
   */
  public void setPictureFile(String fileName) { pictureFile = fileName; }
  
  /**
   * Method to return a string with information about this person
   */
  public String toString()
  {
    return firstName + " " + lastName + " Gender: " + GENDER_ARRAY[gender];
  }
  
  /**
   * Method to compare this Person and a passed one 
   * @param object the object to compare to
   * @return negative if this is less, 0 if equal, and positive if greater
   */
  public int compareTo(Object object)
  {
    int result = -1;
    Person comparePerson = null;
    
    // if the object isn't null and the object is an instance of person
    if (object != null && object instanceof Person)
    {
      comparePerson = (Person) object;
      result = lastName.compareTo(comparePerson.lastName);
      
      // if the result of comparing the last names is the same compare the
      // first names
      if (result == 0)
        result = firstName.compareTo(comparePerson.firstName);
    }
    
    return result;
  }
  
  /**
   * Main method for testing
   */
  public static void main(String[] argv) 
  {
    Person sally = new Person("Sally","Summers",null);
    Person bob = new Person("Bob","Summers",null);
    System.out.println("Compare Sally and Bob " + sally.compareTo(bob));
    System.out.println("Compare Bob and Sally " + bob.compareTo(sally));
    System.out.println("Compare Bob and Bob " + bob.compareTo(bob));
  }
  
}