
/**
 * Class that represents a student.  A student has a unique id, 
 * first name, last name, nickname, a file with their picture 
 * in it, and an array of grades
 */
public class Student extends Person
{
  
  ////////////// fields //////////////////////////////
  
  /** unique identifier for this student */
  private int id;
  
  /** nickname for this student */
  private String nickname;
  
  /** An array of grades for this student */
  private double[] grades; 
  
  /** The number of grades set in the grade array */
  private int numGrades = 0;
  
  /** The count of the number of students */
  private static int numStudents = 0; // start with no students
  
  //////////////// constructors //////////////////////////
  
  /** 
   * No argument constructor.  Set the id.
   */
  public Student() 
  {
    // increment the number of students
    numStudents++;
    
    // set the student id to the current count of students
    id = numStudents;
  }
  
  /**
   * Constructor that takes the first name, last name, and the number of grades
   * @param firstName the first name to use
   * @param lastName the last name to use
   * @param numGrades the number of grades this student will have
   */
  public Student(String firstName, String lastName, int numGrades)
  {
    // set the id using the no-arg constructor
    this();
    
    // set the first and last name fields to the passed strings
    setFirstName(firstName);
    setLastName(lastName);
    
    // create the array of grades
    grades = new double[numGrades];
  }
  
  /**
   * Constructor that takes all the data
   * @param firstName the first name to use
   * @param lastName the last name to use
   * @param nickname the nickname to use
   * @param pictureFile the name of the picture file
   * @param numGrades the number of grades 
   */
   public Student(String firstName, String lastName, String nickname, 
                 String pictureFile, int numGrades)
  {
    // use other constructor to handle part of this
    this(firstName, lastName, numGrades);
    
    // set the nickname and picture file
    this.nickname = nickname;
    this.setPictureFile(pictureFile);
  }
  
  ////////////////////////// methods //////////////////////////////
   
   /**
    * Method to check if the passed object is equal to the current object.
    * @return true if the id's are equal else false
    */
   public boolean equals(Object obj)
   {
     Student testStudent = null;
     boolean result = false;
     
     // if the object isn't null and is of the class Student
     if (obj != null && obj instanceof Student)
     {
       // it is a student so cast it to student
       testStudent = (Student) obj;
       
       // set the result to the check for equal on the ids
       result = (testStudent.id == id);
     }
     
     return result;
   }
   
   /**
    * Method to get a hashcode for this object.  A hashcode doesn't have to 
    * unique but since we have an id we can use this
    */
   public int hashCode() { return id; }
  
  /**
   * Method to get the nickname
   * @return the nickname for this student
   */
  public String getNickname() { return nickname; }
  
  /**
   * Method to set the nickname
   * @param nickname the nickname to use
   */
  public void setNickname(String nickname) { this.nickname = nickname; }
  
  /**
   * Method to add a grade to the grade array
   * @param grade the grade to add
   */
  public void addGrade(double grade)
  {
    if (grades != null && numGrades < grades.length)
    {
      grades[numGrades] = grade;
      numGrades++;
    }
  }
  
  /** 
   * Method to calculate the grade point 
   * @return the grade point average
   */
  public double getGradePointAverage() 
  {
    double total = 0;
    for (int i = 0; i < numGrades ; i++)
      total = total + grades[i];
    double average = 0;
    
    // if the number of grades is > 0 calcuate the average
    if (numGrades > 0)
      average = total / numGrades;
    
    return average;
  }
  
  /**
   * Method to return a string with information about this student
   */
  public String toString()
  {
    return "Student: " + id + " " + super.toString() + " gpa: " + 
      getGradePointAverage();
  }
  
  /**
   * Main method for testing
   */
  public static void main(String[] argv) 
  {
    Student sally = new Student("Sally","Summers",5);
    sally.addGrade(75);
    sally.addGrade(85);
    sally.addGrade(63);
    sally.addGrade(90);
    sally.addGrade(78);
    System.out.println(sally);
    System.out.println("Test sally equals sally " + sally.equals(sally));
    Student tom = new Student("Tom", "Miller",3);
    System.out.println(tom);
    System.out.println("Test sally equals tom " + sally.equals(tom));
  }
    
      
  
  
}