import java.text.*;

/**
 * Class that represents a teacher.  A teacher has a first name,
 * last name, a file with their picture in it, and a salary
 */
public class Teacher extends Person
{
  
  ////////////// fields //////////////////////////////
  
  /** the salary for this teacher */
  private double salary;
  
  /** the number of months this teacher works */
  private int numberMonthsForSalary = 10; // the default is 10 months of work for the salary
  
  //////////////// constructors //////////////////////////
  
  /** 
   * No argument constructor.  All fields have their default values 
   */
  public Teacher() {}
  
  /**
   * Constructor that takes the first name, last name, and the salary
   * @param firstName the first name to use
   * @param lastName the last name to use
   * @param salary the salary for this teacher
   */
  public Teacher(String firstName, String lastName, double salary)
  {
    // let the parent set the first and last name 
    super(firstName,lastName);
    
    // set the salary
    this.salary = salary;
  }
  
  /**
   * Constructor that takes all the data
   * @param firstName the first name to use
   * @param lastName the last name to use
   * @param pictureFile the name of the picture file
   * @param salary the salary for this teacher
   */
  public Teacher(String firstName, String lastName, 
                 String pictureFile, double salary)
  {
    // use the parent constructor to handle part of this
    super(firstName, lastName, pictureFile);
    
    // set the salary
    this.salary = salary;
  }
  
  ////////////////////////// methods //////////////////////////////
  
  /**
   * Method to get the salary for this teacher 
   * @return the salary
   */
  public double getSalary() { return salary; }
  
  /**
   * Method to compute the monthly pay 
   * @return the monthly pay assuming 9 months of work for the salary
   */
  public String getMonthlyPay()
  {
    // get a number formatter that handles formatting currency (money)
    NumberFormat formatter = NumberFormat.getCurrencyInstance();
    
    // calculate the monthly pay
    double pay = salary / numberMonthsForSalary;
    
    // return the pay formatted as currency
    return formatter.format(pay);
  }
  
  /**
   * Method to return a string with information about this teacher
   */
  public String toString()
  {
    return "Teacher: " + super.toString() + " monthly pay: " + 
       getMonthlyPay();
  }
  
  /**
   * Main method for testing
   */
  public static void main(String[] argv) 
  {
    Teacher mary = new Teacher("Mary","Sweeney",52325.25);
    System.out.println(mary);
  }
    
      
  
  
}