
/**
 * Class that represents a binary tree.  A binary tree is made up of
 * tree nodes.  Each tree node can have one parent and up to two children
 * @author Barb Ericson
 * Copyright 2004 Georgia Tech
 */
public class BinaryTree 
{
  //////////// fields ////////////////
  private TreeNode root;
  
  ///////////// constructors /////////////
  
  /** 
   * Constructor that takes no arguments.  The root is null
   */
  public BinaryTree () {}
  
  /**
   * Constructor that takes the root tree node
   * @param node the tree node that will be the root
   */
  public BinaryTree (TreeNode node) { root = node; }
  
  //////////////// methods ////////////////////////////
  
  /**
   * Method to get the root node
   * @return the root node which may be null
   */
  public TreeNode getRoot() { return root; }
  
  /**
   * Method to set the root node
   * @param node the node to use as the root
   */
  public void setRoot(TreeNode node) { root = node; }
  
  /**
   * Method to get the number of nodes in the tree
   */
  public int getNumNodes() 
  {
    int count = 0; // the default is no nodes in the tree
    
    // if the root isn't null get the number of nodes 
    if (root != null)
      count = root.getNumNodes();
    
    return count;
  }
  
  /**
   * Method to print out the values at the nodes in the tree
   * using a pre-order traversal
   */
  public void preOrderPrint()
  {
    // if root isn't null tell it to print using pre-order
    if (root != null)
      root.preOrderPrint();
  }
  
  /**
   * Method to print out the values at the nodes in the tree
   * using an in-order traversal
   */
  public void inOrderPrint()
  {
    // if root isn't null tell it to print using in-order
    if (root != null)
      root.inOrderPrint();
  }
  
  /**
   * Method to print out the values at the nodes in the tree
   * using a post-order traversal
   */
  public void postOrderPrint()
  {
    // if root isn't null tell it to print using post-order
    if (root != null)
      root.postOrderPrint();
  }
  
  /** example static method that is used in many books, but this should
   * be an object method in the TreeNode class
   */
//  public static int getNumNodes(TreeNode node)
//  {
//    if (node == null)
//      return 0;
//    else
//      return 1 + getNumNodes(node.getLeft()) + getNumNodes(node.getRight());
//  }
  
  /**
   * Main method for testing
   */
  public static void main(String[] argv)
  {
    TreeNode node1 = new TreeNode("Opal Peters",null,null);
    TreeNode node2 = new TreeNode("Franics Hund",null,null);
    TreeNode node3 = new TreeNode("Edna Wenzel",null,null);
    TreeNode node4 = new TreeNode("Edward Ericson",null,null);
    TreeNode node5 = new TreeNode("Janet Hund",node1,node2);
    TreeNode node6 = new TreeNode("Charles Ericson",node3,node4);
    TreeNode node7 = new TreeNode("Barbara Ericson",node5,node6);
    BinaryTree tree = new BinaryTree(node7);
    System.out.println("The number of nodes is " + tree.getNumNodes());
    System.out.println("Pre-order print");
    tree.preOrderPrint();
    System.out.println("In-order print");
    tree.inOrderPrint();
    System.out.println("Post-order print");
    tree.postOrderPrint();
    
  }
}