
/**
 * Tree node for a binary tree.
 * @author Barb Ericson
 * Copyright 2004 Georgia Tech
 */
public class TreeNode
{
  ///////////////// fields ///////////////////////
  
  /** Object stored at a tree node */
  private Object value;
  
  /** Reference to the left child */
  private TreeNode left;
  
  /** Reference to the right child */
  private TreeNode right;
  
  ////////////// constructors ////////////////////////
  
  /**
   * Constructor that take the value to store and 
   * the left and right children nodes 
   * @param value the value to store
   * @param left the left child
   * @param right the right child
   */
  public TreeNode(Object value, TreeNode left, TreeNode right)
  {
    this.value = value;
    this.left = left;
    this.right = right;
  }
  
  ////////////// methods ////////////////////////////
  
  /**
   * Method to get the value for this node
   * @return the value
   */
  public Object getValue() { return value; }
  
  /**
   * Method to get the left child for this node
   * @return the left child or null if none
   */
  public TreeNode getLeft() { return left; }
  
  /**
   * Method to get the right child for this node
   * @return the right child or null if none
   */
  public TreeNode getRight() { return right; }
  
  /**
   * Method to set the value for this node 
   * @param value the value to use
   */
  public void setValue(Object object) { value = object; }
  
  /**
   * Method to set the left child for this node 
   * @param left the left child to use
   */
  public void setLeft(TreeNode left) { this.left = left; }
  
  /**
   * Method to set the right child for this node
   * @param right the right child to use
   */
  public void setRight(TreeNode right) { this.right = right; }
  
  /**
   * Method to print out the values in the tree using
   * a pre-order traversal
   */
  public void preOrderPrint()
  {
    /* print the value at this node */
    System.out.println(value);
    
    /* if there is a left child do the recursive call 
     * on the left child
     */
    if (left != null)
      left.preOrderPrint();
    
    /* if there is a right child do the recursive call 
     * on the right child
     */
    if (right != null)
      right.preOrderPrint();
  }
  
  /**
   * Method to print out the values in the tree using
   * an in-order traversal
   */
  public void inOrderPrint()
  {
    /* if there is a left child do the recursive call 
     * on the left child
     */
    if (left != null)
      left.preOrderPrint();
    
    /* print the value at this node */
    System.out.println(value);
    
    /* if there is a right child do the recursive call 
     * on the right child
     */
    if (right != null)
      right.preOrderPrint();
  }
  
    /**
   * Method to print out the values in the tree using
   * a post-order traversal
   */
  public void postOrderPrint()
  {
    /* if there is a left child do the recursive call 
     * on the left child
     */
    if (left != null)
      left.preOrderPrint();
    
    /* if there is a right child do the recursive call 
     * on the right child
     */
    if (right != null)
      right.preOrderPrint();
    
    /* print the value at this node */
    System.out.println(value);
  }
  
  /**
   * Method to get the number of nodes in the tree 
   * @return the number of nodes in the tree or 0 if none
   */
  public int getNumNodes()
  {
    int count = 0;
    
    // increment count
    count = count + 1;
    
    // add to the count the number of nodes in the left subtree
    if (left != null)
      count = count + left.getNumNodes();
    
    // add the to count the number of nodes in the right subtree
    if (right != null)
      count = count + right.getNumNodes();
    
    return count;
  }
}