
/**
 * Class that represents a node of a linked list.  Each node has a value and 
 * a reference to the next node of the list.
 * @author Barbara Ericson
 * Copyright 2004 Georgia Tech
 */
public class ListNode
{
  ///////////////////// fields /////////////////////////////////
  
  /** holds an object as the value of this node */
  private Object value; 
  
  /** holds the reference to the next node in the linked list or null */
  private ListNode next;
  
  /////////////////////// constructors ////////////////////////
  
  /**
   * Constructor that takes a value and reference to the next node
   * @param value the value to use
   * @param next the next reference to use
   */
  public ListNode(Object value, ListNode next)
  {
    this.value = value;
    this.next = next;
  }
  
  ///////////////////// methods ////////////////////////////////
  
  /**
   * Method to get the value 
   * @return the value stored in this node
   */
  public Object getValue() { return value; }
  
  /**
   * Method to get the next reference
   * @return the next node in the linked list or null if no more
   */
  public ListNode getNext() { return next; }
  
  /**
   * Method to set the value 
   * @param value the value to use
   */
  public void setValue(Object value) { this.value = value; }
  
  /**
   * Method to set the next node
   * @param next the next node to use
   */
  public void setNext(ListNode node) { this.next = node; }
  
}