
/**
 * Class that represents a singly linked list of ListNodes 
 * @author Barb Ericson
 */
public class SinglyLinkedList
{
  ////////////// fields ///////////////////////////
  
  /** The first node in the linked list */
  private ListNode head = null;
  
  ////////////// constructors //////////////////////
  
  /**
   * Constructor that takes no arguments.  The head is null.
   */
  public SinglyLinkedList() { }
  
  /**
   * Constructor that takes the first node in the list 
   * @param firstNode the first node in the linked list
   */
  public SinglyLinkedList(ListNode firstNode) { head = firstNode; }
  
  /////////////////// methods ////////////////////////////
  
  /**
   * Method to get the first node in the linked list 
   * @return the first node in the linked list
   */
  public ListNode getHead() { return head; }
  
  /**
   * Method to set the first node in the linked list
   * @param firstNode the new first node to use
   */
  public void setHead(ListNode firstNode) { head = firstNode; }
  
  /**
   * Method to add a list node to the front of the the linked list
   */
  public void addToFront(ListNode node) 
  {
    // set the new node's next to point to the first node
    node.setNext(head);
    
    // change head to point to the new node
    head = node;
  }
  
  /**
   * Method to add a list node to the end of the linked list
   */
  public void addToEnd(ListNode nodeToAdd)
  {
    ListNode node = null;
    
    // if head is null set head to this node
    if (head == null)
      head = nodeToAdd;
    
    // else there is at least one node in the linked list
    else
    {
      // loop till node points to the last node in the linked list
      for (node = head; node.getNext() != null ; node = node.getNext());
      
      // add the new node
      node.setNext(nodeToAdd);
    }
  }
  
  /**
   * Method to return a string with all the values in the linked list
   * @return a string with all the values in it
   */
  public String toString() 
  {
    String result = "";
    ListNode node = null;
    
    // loop through the nodes adding the node's value 
    for (node = head; node != null; node = node.getNext())
    {
      result = result + node.getValue();
    }
    return result;
  }
  
  /**
   * Method to return the number of nodes in the list 
   * @return the number of nodes in the list
   */
  public int size()
  {
    int num = 0;
    ListNode node = null;
    
    if (head != null)
      for (node = head; node != null; node = node.getNext())
         num++;
    
    return num;
  } 
  
}