import java.text.*;

/**
 * Class that represents a teacher.  A teacher has a first name,
 * last name, a file with their picture in it, and a salary
 */
public class Teacher 
{
  
  ////////////// fields //////////////////////////////
  
  /** first name of this teacher */
  private String firstName;
  
  /** last name of this teacher */
  private String lastName;
  
  /** the name of a file that has a picture of the teacher */
  private String pictureFile;
  
  /** the salary for this teacher */
  private double salary;
  
  /** the number of months this teacher works */
  private int numberMonthsForSalary = 10; // the default is 10 months of work for the salary
  
  //////////////// constructors //////////////////////////
  
  /** 
   * No argument constructor.  All fields have their default values 
   */
  public Teacher() {}
  
  /**
   * Constructor that takes the first name, last name, and the salary
   * @param firstName the first name to use
   * @param lastName the last name to use
   * @param salary the salary for this teacher
   */
  public Teacher(String firstName, String lastName, double salary)
  {
    // set the first and last name fields to the passed strings
    this.firstName = firstName;
    this.lastName = lastName;
    
    // set the salary
    this.salary = salary;
  }
  
  /**
   * Constructor that takes all the data
   * @param firstName the first name to use
   * @param lastName the last name to use
   * @param pictureFile the name of the picture file
   * @param salary the salary for this teacher
   */
  public Teacher(String firstName, String lastName, 
                 String pictureFile, double salary)
  {
    // use other constructor to handle part of this
    this(firstName, lastName, salary);
    
    // set the picture file
    this.pictureFile = pictureFile;
  }
  
  ////////////////////////// methods //////////////////////////////
  
  /** 
   * Method to get the first name
   * @return the first name
   */
  public String getFirstName() { return firstName; }
  
  /**
   * Method to get the last name
   * @return the last name
   */
  public String getLastName() { return lastName; }
  
  /**
   * Method to get the picture file name 
   * @return the name of the file with a picture of the teacher in it
   */
  public String getPictureFile() { return pictureFile; }
  
  /**
   * Method to get the salary for this teacher 
   * @return the salary
   */
  public double getSalary() { return salary; }
  
  /**
   * Method to set the first name
   * @param firstName the first name to use
   */
  public void setFirstName(String firstName) { this.firstName = firstName; }
  
  /**
   * Method to set the last name
   * @param lastName the last name to use
   */
  public void setLastName(String lastName) { this.lastName = lastName; }
  
  /**
   * Method to set the picture file name
   * @param fileName the file name of the picture of this teacher
   */
  public void setPictureName(String fileName) { pictureFile = fileName; }
  
  /**
   * Method to compute the monthly pay 
   * @return the monthly pay assuming 9 months of work for the salary
   */
  public String getMonthlyPay()
  {
    // get a number formatter that handles formatting currency (money)
    NumberFormat formatter = NumberFormat.getCurrencyInstance();
    
    // calculate the monthly pay
    double pay = salary / numberMonthsForSalary;
    
    // return the pay formatted as currency
    return formatter.format(pay);
  }
  
  /**
   * Method to return a string with information about this teacher
   */
  public String toString()
  {
    return "Teacher: " + firstName + " " + lastName + " monthly pay: " + 
       getMonthlyPay();
  }
  
  /**
   * Main method for testing
   */
  public static void main(String[] argv) 
  {
    Teacher mary = new Teacher("Mary","Sweeney",52325.25);
    System.out.println(mary);
  }
    
      
  
  
}